==> chaosmesh-model-6.5.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineSelectorSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;
import java.util.function.Predicate;

 /**
  * Generated
  */
public interface PhysicalMachineSelectorSpecFluent<A extends PhysicalMachineSelectorSpecFluent<A>> extends Fluent<A>{
  public A addToAnnotationSelectors(String key,String value);
  public A addToAnnotationSelectors(Map<String,String> map);
  public A removeFromAnnotationSelectors(String key);
  public A removeFromAnnotationSelectors(Map<String,String> map);
  public Map<String,String> getAnnotationSelectors();
  public <K,V>A withAnnotationSelectors(Map<String,String> annotationSelectors);
  public Boolean hasAnnotationSelectors();
  public A addToExpressionSelectors(Integer index,LabelSelectorRequirement item);
  public A setToExpressionSelectors(Integer index,LabelSelectorRequirement item);
  public A addToExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToExpressionSelectors(Collection<LabelSelectorRequirement> items);
  public A removeFromExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromExpressionSelectors(Collection<LabelSelectorRequirement> items);
  public List<LabelSelectorRequirement> getExpressionSelectors();
  public LabelSelectorRequirement getExpressionSelector(Integer index);
  public LabelSelectorRequirement getFirstExpressionSelector();
  public LabelSelectorRequirement getLastExpressionSelector();
  public LabelSelectorRequirement getMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate);
  public Boolean hasMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate);
  public A withExpressionSelectors(List<LabelSelectorRequirement> expressionSelectors);
  public A withExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... expressionSelectors);
  public Boolean hasExpressionSelectors();
  public A addToFieldSelectors(String key,String value);
  public A addToFieldSelectors(Map<String,String> map);
  public A removeFromFieldSelectors(String key);
  public A removeFromFieldSelectors(Map<String,String> map);
  public Map<String,String> getFieldSelectors();
  public <K,V>A withFieldSelectors(Map<String,String> fieldSelectors);
  public Boolean hasFieldSelectors();
  public A addToLabelSelectors(String key,String value);
  public A addToLabelSelectors(Map<String,String> map);
  public A removeFromLabelSelectors(String key);
  public A removeFromLabelSelectors(Map<String,String> map);
  public Map<String,String> getLabelSelectors();
  public <K,V>A withLabelSelectors(Map<String,String> labelSelectors);
  public Boolean hasLabelSelectors();
  public A addToNamespaces(Integer index,String item);
  public A setToNamespaces(Integer index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(Integer index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToPhysicalMachines(String key,List<String> value);
  public A addToPhysicalMachines(Map<String,List<String>> map);
  public A removeFromPhysicalMachines(String key);
  public A removeFromPhysicalMachines(Map<String,List<String>> map);
  public Map<String,List<String>> getPhysicalMachines();
  public <K,V>A withPhysicalMachines(Map<String,List<String>> physicalMachines);
  public Boolean hasPhysicalMachines();
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PhysicalMachineSelectorSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.util.Collection;
import java.util.List;
import io.fabric8.kubernetes.api.model.LabelSelectorRequirement;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface PhysicalMachineSelectorSpecFluent<A extends PhysicalMachineSelectorSpecFluent<A>> extends Fluent<A>{
  public A addToAnnotationSelectors(String key,String value);
  public A addToAnnotationSelectors(Map<String,String> map);
  public A removeFromAnnotationSelectors(String key);
  public A removeFromAnnotationSelectors(Map<String,String> map);
  public Map<String,String> getAnnotationSelectors();
  public <K,V>A withAnnotationSelectors(Map<String,String> annotationSelectors);
  public Boolean hasAnnotationSelectors();
  public A addToExpressionSelectors(int index,LabelSelectorRequirement item);
  public A setToExpressionSelectors(int index,LabelSelectorRequirement item);
  public A addToExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A addAllToExpressionSelectors(Collection<LabelSelectorRequirement> items);
  public A removeFromExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... items);
  public A removeAllFromExpressionSelectors(Collection<LabelSelectorRequirement> items);
  public List<LabelSelectorRequirement> getExpressionSelectors();
  public LabelSelectorRequirement getExpressionSelector(int index);
  public LabelSelectorRequirement getFirstExpressionSelector();
  public LabelSelectorRequirement getLastExpressionSelector();
  public LabelSelectorRequirement getMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate);
  public Boolean hasMatchingExpressionSelector(Predicate<LabelSelectorRequirement> predicate);
  public A withExpressionSelectors(List<LabelSelectorRequirement> expressionSelectors);
  public A withExpressionSelectors(io.fabric8.kubernetes.api.model.LabelSelectorRequirement... expressionSelectors);
  public Boolean hasExpressionSelectors();
  public A addToFieldSelectors(String key,String value);
  public A addToFieldSelectors(Map<String,String> map);
  public A removeFromFieldSelectors(String key);
  public A removeFromFieldSelectors(Map<String,String> map);
  public Map<String,String> getFieldSelectors();
  public <K,V>A withFieldSelectors(Map<String,String> fieldSelectors);
  public Boolean hasFieldSelectors();
  public A addToLabelSelectors(String key,String value);
  public A addToLabelSelectors(Map<String,String> map);
  public A removeFromLabelSelectors(String key);
  public A removeFromLabelSelectors(Map<String,String> map);
  public Map<String,String> getLabelSelectors();
  public <K,V>A withLabelSelectors(Map<String,String> labelSelectors);
  public Boolean hasLabelSelectors();
  public A addToNamespaces(int index,String item);
  public A setToNamespaces(int index,String item);
  public A addToNamespaces(java.lang.String... items);
  public A addAllToNamespaces(Collection<String> items);
  public A removeFromNamespaces(java.lang.String... items);
  public A removeAllFromNamespaces(Collection<String> items);
  public List<String> getNamespaces();
  public String getNamespace(int index);
  public String getFirstNamespace();
  public String getLastNamespace();
  public String getMatchingNamespace(Predicate<String> predicate);
  public Boolean hasMatchingNamespace(Predicate<String> predicate);
  public A withNamespaces(List<String> namespaces);
  public A withNamespaces(java.lang.String... namespaces);
  public Boolean hasNamespaces();
  public A addToPhysicalMachines(String key,List<String> value);
  public A addToPhysicalMachines(Map<String,List<String>> map);
  public A removeFromPhysicalMachines(String key);
  public A removeFromPhysicalMachines(Map<String,List<String>> map);
  public Map<String,List<String>> getPhysicalMachines();
  public <K,V>A withPhysicalMachines(Map<String,List<String>> physicalMachines);
  public Boolean hasPhysicalMachines();
  
}
